@@ -3,7 +3,7 @@
  *
  * Licensed under the LGPL, see LICENSE file for more information.
  *
- * $Header: /cvs/cairo/cairo-perl/cairo-perl-private.h,v 1.6 2007-09-30 12:54:32 tsch Exp $
+ * $Id$
  *
  */
 
@@ -33,4 +33,10 @@ const char * cairo_perl_package_table_lookup (void *pointer);
 		croak (Nullch);					\
 	}
 
+#define cairo_perl_sv_is_array_ref(sv) \
+	(SvOK (sv) && SvROK (sv) && SvTYPE (SvRV(sv)) == SVt_PVAV)
+
+#define cairo_perl_sv_is_hash_ref(sv) \
+	(SvOK (sv) && SvROK (sv) && SvTYPE (SvRV(sv)) == SVt_PVHV)
+
 #endif /* _CAIRO_PERL_PRIVATE_H_ */
